
/* Klasse Matrix implemtiert 2D Arrays.
 */
public class Matrix {

    private int[][] m;    // Matrix
    private int rows;     // Anzahl der Zeilen
    private int cols;     // Anzahl der Spalten

    /* Konstruktor zur Initialisierung dieser Matrix. Der bergebene Parameter 
     * besitzt mindestens eine Zeile und eine Spalte.
     *
     * Parameter:
     *    int[][] m - eine nichtleere Matrix
     */
    public Matrix(int[][] m) {
	this.m = m;
	this.rows = m.length;
	this.cols = m[0].length;
    }

    /* Setzt spezifziertes Matrixelement auf spezifizierten Wert val. Die 
     * Parameter r und c liegen innerhalb des gueltigen Bereichs.
     *
     * Parameter:
     *    int r - Zeile des Matrixelements
     *    int c - Spalte des Matrixelements
     *    int val - Wert
     */
    public void setValue(int r, int c, int val) {
	m[r][c] = val;
    }

    /* Liefert spezifiziertes Matrixelement zurueck. Die Parameter r und c 
     * liegen innerhalb des gueltigen Bereichs.
     *
     * Parameter:
     *    int r - Zeile des Matrixelements
     *    int c - Spalte des Matrixelements
     *
     * Return:
     *    int - Matrixelement
     */
    public int getValue(int r, int c) {
	return m[r][c];
    }

    /* Liefert Anzahl der Matrixelemente mit spezifizierten Wert zurueck.
     *
     * Parameter:
     *     int val - ein Wert
     * 
     * Return:
     *     int - Anzahl der Matrixelemente mit Wert val
     */
    public int count(int val) {
	int n = 0;
	for(int i = 0; i < rows; i++) {
	    for(int j = 0; j < cols; j++) {
		if(m[i][j] == val) {
		    n = n + 1;
		}
	    }
	}
	return n;
    }

    /* Liefert Maximum aller Matrixelemente zurueck.
     * 
     * Return:
     *     int - Maximum aller Matrixelemente
     */
    public int max() {
	int maximum = m[0][0];
	for(int i = 0; i < rows; i++) {
	    for(int j = 0; j < cols; j++) {
		maximum = Math.max(m[i][j], maximum);
	    }
	}
	return maximum;
    }

    /* Liefert Zeilensummen zurueck.
     *
     * Return:
     *     int[] - Zeilensummen
     */
    public int[] zeilenSumme() {
	int[] sum = new int[rows];
	for(int i = 0; i < rows; i++) {
	    sum[i] = 0;
	    for(int j = 0; j < cols; j++) {
		sum[i] = sum[i] + m[i][j];
	    }
	}
	return sum;
    }

    /* Liefert Stringrepraesentation dieser Matrix zurueck.
     *
     * Return:
     *     String - Stringrepraesentation dieser Matrix
     */ 
    public String toString() {
	String str = "";
	for(int i = 0; i < rows; i++) {
	    for(int j = 0; j < cols; j++) {
		str = str + m[i][j] + " ";
	    }
	    str = str + "\n";
	}
	return str;
    }

}
