/* Version 1 des Tarifrechners fuer Strom. In dieser Version besitzen die 
 * verschiedenen Tarife kein gemeinsames Interface. Es treten deswegen eine 
 * Reihe von Problemen auf, die unten aufgezeigt werden.
 */
public class TarifRechner {

    /* Tarife
     * Problem: Jeder Tarif wird einzeln als Attribut aufgelistet. In der Praxis
     *          existieren mehrere Dutzend Anbieter auf dem Markt, die verwaltet
     *          werden muessen.
     * Ausweg: Java API-Klasse ArrayList (haben wir noch nicht gehabt)
     */
    private EPrimo eprimo;
    private Nuon nuon;
    private Vattenfall vfall;

    /* Konstruktor zur Initialisierung der Tarife.
     *
     * Problem: 
     *     - Umstaendliche Initialisierung bei vielen Tarifen.
     *
     * Parameter:
     *     EPrimo eprimo - Tarif des Versorgers EPrimo
     *     Nuon nuon - Tarif des Versorgers Nuon
     *     Vattenfall vfall - Tarif des Versorgers Vattenfall
     */
    public TarifRechner(EPrimo eprimo, Nuon nuon, Vattenfall vfall) {
	this.eprimo = eprimo;
	this.nuon = nuon;
	this.vfall = vfall;
    }

    /* Liefert besten Tarif bei gegebenem Verbrauch zurueck.
     *
     * Problem: 
     *      - Jeder Tarif muss in einer separaten Anweisung berechnet werden.
     *      - Was soll zurueck geliefert werden? Versorger oder Kosten?
     *
     * Parameter:
     *     double kwh - Verbrauch in kWh (nicht-negativ)
     *
     * Return:
     *     Tarif - Tarif mit geringsten Kosten
     */
    public double getBestTarif(double kwh) {

	double min = Double.MAX_VALUE;
	if(eprimo != null) {
	    double t = eprimo.berechne(kwh);
	    if(t < min) {
		min = t;
	    }
	}
	if(nuon != null) {
	    double t = nuon.berechne(kwh);
	    if(t < min) {
		min = t;
	    }
	}
	if(vfall != null) {
	    double t = vfall.berechne(kwh);
	    if(t < min) {
		min = t;
	    }
	}
	return min;
    }
}